==> humhub-1.17.4.zip: humhub-1.17.4/protected/humhub/modules/admin/messages/am/information.php <==
<?php

return [
    '<strong>CronJob</strong> Status' => '<strong>የበክሮን ስራ</strong> ሁኔታ',
    '<strong>Queue</strong> Status' => '<strong>የተራ</strong> ሁኔታ',
    'About HumHub' => 'ስለ HumHub',
    'Background Jobs' => 'ዳራዊ ስራ',
    'Base URL' => 'የURL መሰረት',
    'Database' => 'ዳታቤዝ',
    'Database migration results:' => 'የዳታቤዝ ሽግግር ውጤቶች፡',
    'Delayed' => 'ዘግይቷል',
    'Displaying {count} entries per page.' => 'በየገፁ የገቡትን {count} በማሳየት ላይ',
    'Done' => 'ተከናውኗል',
    'Driver' => 'አንቀሳቃሽ',
    'Error' => 'ስህተት',
    'Flush entries' => 'የገቡ ማስወገጃ ',
    'HumHub is currently in debug mode. Disable it when running on production!' => 'HumHub በአሁኑ ጊዜ በእርማት ሞድ ላይ ይገኛል። ወደስራ ሂደት ሲገቡ እንዳይሰራ ያድርጉት።',
    'Last run (daily):' => 'የመጨረሻ እንቅስቃሴ (ዕለታዊ)',
    'Last run (hourly):' => 'የመጨረሻ እንቅስቃሴ (በየሰዓቱ)',
    'Licences' => 'ፈቃዶች',
    'Logging' => 'የምዝገባ ማስታወሻ',
    'Never' => 'ፈፅሞ',
    'Permissions' => 'ፈቃዶች',
    'Please refer to the documentation to setup the cronjobs and queue workers.' => 'እባክዎን የክሮንስራውን እና የተራ ስራውን ለማስተካከል ሰነዱን ይመልከቱ።',
    'Prerequisites' => 'ቅድመ ሁኔታዎች',
    'Queue successfully cleared.' => 'ተራው በተሳካ ሁኔታ ተወግዷል።',
    'Reserved' => 'የተያዘ',
    'Search index rebuild in progress.' => 'የፍለጋ ማውጫው ዳግም ግንባታ በሂደት ላይ ነው።',
    'See installation manual for more details.' => 'ለዝርዝሩ የመግጠሚያ መመሪያውን ይመልከቱ። ',
    'Settings' => 'ማስተካከያዎች',
    'The current main HumHub database name is ' => 'አሁን ያለው ዋነኛ የHumHub ዳታቤዝ ስም',
    'There is a new update available! (Latest version: %version%)' => 'አዲስ የሚያዘምኑት ሞጁል አለ! (የምጨረሻ ጊዜ ምርት: %version%)',
    'This HumHub installation is up to date!' => 'ይህ የተጫነው HumHub የዘመነ ነው!',
    'Total {count} entries found.' => 'በጠቅላላው {count} ገብተው ተገኝተዋል።',
    'Waiting' => 'በጥበቃ ላይ...',
    '"Push Notifications (Firebase)" module and setup of Firebase API Key required' => '',
    'Assets' => '',
    'Checking HumHub software prerequisites.' => '',
    'Configuration File' => '',
    'Current limit is: {currentLimit}' => '',
    'Custom Modules ({modules})' => '',
    'Database collation' => '',
    'Database driver - {driver}' => '',
    'Deprecated Modules ({modules})' => '',
    'Detected URL: {currentBaseUrl}' => '',
    'Different table collations in the tables: {tables}' => '',
    'Disabled Functions' => '',
    'Dynamic Config' => '',
    'HumHub' => '',
    'HumHub Documentation' => '',
    'ICU Data Version ({version})' => '',
    'ICU Data {icuMinVersion} or higher is required' => '',
    'ICU Version ({version})' => '',
    'ICU {icuMinVersion} or higher is required' => '',
    'Increase memory limit in {fileName}' => '',
    'Info' => '',
    'Install {phpExtension} Extension' => '',
    'Install {phpExtension} Extension for APC Caching' => '',
    'Install {phpExtension} Extension for e-mail S/MIME support.' => '',
    'Make sure that the `proc_open` function is not disabled.' => '',
    'Make {filePath} writable for the Webserver/PHP!' => '',
    'Marketplace API Connection' => '',
    'Memory Limit ({memoryLimit})' => '',
    'Minimum Version {minVersion}' => '',
    'Mobile App - Push Service' => '',
    'Module Directory' => '',
    'Multibyte String Functions' => '',
    'Must be updated manually. Check compatibility with newer HumHub versions before updating.' => '',
    'New migrations should be applied: {migrations}' => '',
    'No pending migrations' => '',
    'Optional' => '',
    'Other' => '',
    'Outstanding database migrations:' => '',
    'Pretty URLs' => '',
    'Profile Image' => '',
    'Re-Run tests' => '',
    'Rebuild search index' => '',
    'Recommended collation is {collation}' => '',
    'Recommended collation is {collation} for the tables: {tables}' => '',
    'Recommended engine is {engine} for the tables: {tables}' => '',
    'Refresh' => '',
    'Runtime' => '',
    'Search term...' => '',
    'Select category..' => '',
    'Select day' => '',
    'Select level...' => '',
    'Supported drivers: {drivers}' => '',
    'Table collations' => '',
    'Table engines' => '',
    'The configuration file contains legacy settings. Invalid options: {options}' => '',
    'The module(s) are no longer maintained and should be uninstalled.' => '',
    'Trace' => '',
    'Update Database' => '',
    'Uploads' => '',
    'Varying table engines are not supported.' => '',
    'Version' => '',
    'Warning' => '',
    'Web Application PHP version: `{webPhpVersion}`, Cron PHP Version: `{cronPhpVersion}`' => '',
    'Web Application and Cron uses the same PHP version' => '',
    'Web Application and Cron uses the same user' => '',
    'Web Application user: `{webUser}`, Cron user: `{cronUser}`' => '',
    'Your database is <b>up-to-date</b>.' => '',
    '{imageExtension} Support' => '',
    '{phpExtension} Extension' => '',
    '{phpExtension} Support' => '',
];

==> humhub-1.18.0.zip: humhub-1.18.0/protected/humhub/modules/admin/messages/am/information.php <==
<?php

return [
    '<strong>CronJob</strong> Status' => '<strong>የበክሮን ስራ</strong> ሁኔታ',
    '<strong>Queue</strong> Status' => '<strong>የተራ</strong> ሁኔታ',
    'About HumHub' => 'ስለ HumHub',
    'Background Jobs' => 'ዳራዊ ስራ',
    'Base URL' => 'የURL መሰረት',
    'Database' => 'ዳታቤዝ',
    'Database migration results:' => 'የዳታቤዝ ሽግግር ውጤቶች፡',
    'Delayed' => 'ዘግይቷል',
    'Displaying {count} entries per page.' => 'በየገፁ የገቡትን {count} በማሳየት ላይ',
    'Done' => 'ተከናውኗል',
    'Driver' => 'አንቀሳቃሽ',
    'Error' => 'ስህተት',
    'Flush entries' => 'የገቡ ማስወገጃ ',
    'HumHub is currently in debug mode. Disable it when running on production!' => 'HumHub በአሁኑ ጊዜ በእርማት ሞድ ላይ ይገኛል። ወደስራ ሂደት ሲገቡ እንዳይሰራ ያድርጉት።',
    'Last run (daily):' => 'የመጨረሻ እንቅስቃሴ (ዕለታዊ)',
    'Last run (hourly):' => 'የመጨረሻ እንቅስቃሴ (በየሰዓቱ)',
    'Licences' => 'ፈቃዶች',
    'Logging' => 'የምዝገባ ማስታወሻ',
    'Never' => 'ፈፅሞ',
    'Permissions' => 'ፈቃዶች',
    'Please refer to the documentation to setup the cronjobs and queue workers.' => 'እባክዎን የክሮንስራውን እና የተራ ስራውን ለማስተካከል ሰነዱን ይመልከቱ።',
    'Prerequisites' => 'ቅድመ ሁኔታዎች',
    'Queue successfully cleared.' => 'ተራው በተሳካ ሁኔታ ተወግዷል።',
    'Reserved' => 'የተያዘ',
    'Search index rebuild in progress.' => 'የፍለጋ ማውጫው ዳግም ግንባታ በሂደት ላይ ነው።',
    'See installation manual for more details.' => 'ለዝርዝሩ የመግጠሚያ መመሪያውን ይመልከቱ። ',
    'Settings' => 'ማስተካከያዎች',
    'The current main HumHub database name is ' => 'አሁን ያለው ዋነኛ የHumHub ዳታቤዝ ስም',
    'There is a new update available! (Latest version: %version%)' => 'አዲስ የሚያዘምኑት ሞጁል አለ! (የምጨረሻ ጊዜ ምርት: %version%)',
    'This HumHub installation is up to date!' => 'ይህ የተጫነው HumHub የዘመነ ነው!',
    'Total {count} entries found.' => 'በጠቅላላው {count} ገብተው ተገኝተዋል።',
    'Waiting' => 'በጥበቃ ላይ...',
    '"Push Notifications (Firebase)" module and setup of Firebase API Key required' => '',
    'Assets' => '',
    'Checking HumHub software prerequisites.' => '',
    'Configuration File' => '',
    'Current limit is: {currentLimit}' => '',
    'Custom Modules ({modules})' => '',
    'Database collation' => '',
    'Database driver - {driver}' => '',
    'Deprecated Modules ({modules})' => '',
    'Detected URL: {currentBaseUrl}' => '',
    'Different table collations in the tables: {tables}' => '',
    'Disabled Functions' => '',
    'Enable <a href="{url}">Link Redirection Service</a>' => '',
    'HumHub' => '',
    'HumHub Documentation' => '',
    'ICU Data Version ({version})' => '',
    'ICU Data {icuMinVersion} or higher is required' => '',
    'ICU Version ({version})' => '',
    'ICU {icuMinVersion} or higher is required' => '',
    'Increase memory limit in {fileName}' => '',
    'Info' => '',
    'Install {phpExtension} Extension' => '',
    'Install {phpExtension} Extension for APC Caching' => '',
    'Install {phpExtension} Extension for Mercure push live driver' => '',
    'Install {phpExtension} Extension for e-mail S/MIME support.' => '',
    'Make sure that the `proc_open` function is not disabled.' => '',
    'Make {filePath} writable for the Webserver/PHP!' => '',
    'Marketplace API Connection' => '',
    'Memory Limit ({memoryLimit})' => '',
    'Minimum Version {minVersion}' => '',
    'Mobile App - Push Service' => '',
    'Module Directory' => '',
    'Multibyte String Functions' => '',
    'Must be updated manually. Check compatibility with newer HumHub versions before updating.' => '',
    'New migrations should be applied: {migrations}' => '',
    'No pending migrations' => '',
    'Optional' => '',
    'Other' => '',
    'Outstanding database migrations:' => '',
    'Pretty URLs' => '',
    'Profile Image' => '',
    'Re-Run tests' => '',
    'Rebuild search index' => '',
    'Recommended collation is {collation}' => '',
    'Recommended collation is {collation} for the tables: {tables}' => '',
    'Recommended engine is {engine} for the tables: {tables}' => '',
    'Refresh' => '',
    'Runtime' => '',
    'Search term...' => '',
    'Select category..' => '',
    'Select day' => '',
    'Select level...' => '',
    'Supported drivers: {drivers}' => '',
    'Table collations' => '',
    'Table engines' => '',
    'The configuration file contains legacy settings. Invalid options: {options}' => '',
    'The module(s) are no longer maintained and should be uninstalled.' => '',
    'Trace' => '',
    'Update Database' => '',
    'Uploads' => '',
    'Uploads - File' => '',
    'Varying table engines are not supported.' => '',
    'Version' => '',
    'Warning' => '',
    'Web Application PHP version: `{webPhpVersion}`, Cron PHP Version: `{cronPhpVersion}`' => '',
    'Web Application and Cron uses the same PHP version' => '',
    'Web Application and Cron uses the same user' => '',
    'Web Application user: `{webUser}`, Cron user: `{cronUser}`' => '',
    'Your database is <b>up-to-date</b>.' => '',
    '{imageExtension} Support' => '',
    '{phpExtension} Extension' => '',
    '{phpExtension} Support' => '',
];
